<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:TEI="http://www.tei-c.org/ns/1.0" xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl" exclude-result-prefixes="xs xd" version="2.0">
    <xsl:output method="html" encoding="UTF-8" indent="yes" omit-xml-declaration="yes"/>

    <xsl:variable name="imageWidth">
        <!-- Variable für die Bildbreite, das px wird dabei abgeschnitten -->
        
        <xsl:choose>
            <xsl:when test="//TEI:facsimile/TEI:surface/TEI:graphic/@width">
                <xsl:value-of
                    select="replace(//TEI:facsimile/TEI:surface/TEI:graphic/@width, 'px', '')"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>0</xsl:text>
            </xsl:otherwise>
        </xsl:choose>    </xsl:variable>

    <xsl:variable name="imageHeight">
        <!-- Variable für die Bildhöhe -->
        <xsl:choose>
            <xsl:when test="//TEI:facsimile/TEI:surface/TEI:graphic/@height">
                <xsl:value-of
                    select="replace(//TEI:facsimile/TEI:surface/TEI:graphic/@height, 'px', '')"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>0</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <xsl:template match="TEI:TEI">
        <!-- HTML5 Grundgerüst bauen -->

        <xsl:text disable-output-escaping="yes">&lt;!DOCTYPE html>
        </xsl:text>
        <html xmlns="http://www.w3.org/1999/xhtml">
            <head>
                <meta charset="UTF-8"/>
                <title>Testtransformation für TEI facsimile-Element </title>

                <!-- Javascriptfunktionen, um auf dem angezeigten Bild die zone-Elemente zu markieren  -->
                <script type="text/javascript">
            
      function draw(ulx,uly,lrx,lry,ratio){                                         // zeichnet ein Rechteck mit den angegebenen Koordinaten
                                                                                                             // ratio gibt die Vergrößerng/Verkleinerung an. 0.5 = 50%
                                                                                                            // Funktion wird immer aufgerufen, wenn die Maus auf ein span-Element wegbewegt wird
        var canvas = document.getElementById('canvas1');       // Element  mit id="canvas1" suchen
        if (canvas.getContext){                                                            // prüfen, ob Element die getContext()-Funktion hat, d.h., ob der Browser HTML5-fähig ist
          var ctx = canvas.getContext('2d');                                       // falls ja, 2D-Context (d.h. die Zeichenfläche) auslesen          
          var x = ulx * ratio;                                                                    // Koordinaten berechnen
          var y = uly * ratio;
          var rectwidth = (lrx - ulx) * ratio;                                          // Höhe und Breite aus den Koordinaten berechnen
          var rectheight = (lry - uly) * ratio;
 
          ctx.strokeStyle = "rgba(0,0,0,1)";                                        // Umrandungsfarbe auf schwarz setzen
          ctx.fillStyle = "rgba(255,0,0,0.2)";                                      // Füllfarbe auf rot und leicht transparent setzen
          ctx.strokeRect(x,y,rectwidth,rectheight);                           // Umrandung malen
          ctx.fillRect(x,y,rectwidth,rectheight);                                   // Füllung malen
        }
      };
       
     function erase(){                                                                      // löscht den Inhalt der Zeichenfläche.
                                                                                                            // Funktion wird immer aufgerufen, wenn die Maus von einem span-Element wegbewegt wird
        var canvas = document.getElementById('canvas1');
        if (canvas.getContext){
          var ctx = canvas.getContext('2d');
                  ctx.clearRect(0,0,canvas.width,canvas.height);        }
      };

    </script>
            </head>
            <body>

                <!-- div für den Text, links positioniert -->
                <div id="textarea" style="position:absolute;top:10px;left:10px;width:400px;">
                    <xsl:apply-templates select="TEI:text"/>
                </div>


                <!-- div für das Bild, neben dem Textbereich positioniert, der z-index schiebt das Bild immer in den Hintergrund -->
                <!-- Bild wird hier standardmäßig 50% verkleinert (*0.5) -->
                <div id="imageArea"
                    style="position:absolute;top:10px;left:420px;width:600px;z-index:-1;">
                    <img src="{//TEI:facsimile/TEI:surface/TEI:graphic/@url}"
                        width="{$imageWidth*0.5}" height="{$imageHeight*0.5}"
                        alt="Hier sollte die Grafik stehen"/>
                </div>


                <!-- div für die Zeichenfläche, direkt über dem Bild positioniert -->
                <!-- Größe entspricht der Bildgröße bzw. hier standardmäßig auf 50% verkleinert -->
                <div id="canvasArea" style="position:absolute;top:10px;left:420px;width:600px;">
                    <canvas id="canvas1" width="{$imageWidth*0.5}" height="{$imageHeight*0.5}">
                        <p style="font-style:large">Hier sollte die Zeichenfläche sein!</p>
                    </canvas>
                </div>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="TEI:teiHeader">
        <!-- Header wird nicht ausgewertet -->
    </xsl:template>

    <xsl:template match="TEI:facsimile">
        <!-- facsimile-Element wird an dieser Stelle nicht ausgewertet -->
    </xsl:template>

    <xsl:template match="*">
        <!-- Template für w und seg, in denen ggf. facs-Attribute angegeben sind-->

        <!-- Variable für die ID der  Zone definieren (die Raute dabei wegschneiden) -->
        <xsl:variable name="zoneID">
            <xsl:value-of select="replace(@facs, '#', '')"/>
        </xsl:variable>

        <!-- wenn ein @facs angegeben ist, dann die Koordinaten aus dem zugehörigen zone-Element holen, sonst einfach weiter -->
        <xsl:choose>
            <xsl:when test="@facs">
                <span>

                    <!-- Attribut mit mouseover-Handler, ruft die draw-Funktion mit den Koordinaten aus dem zone-Element auf, ratio hier auf 0.5 gesetzt -->
                    <xsl:attribute name="onmouseover">
                        <xsl:text>draw(</xsl:text>
                        <xsl:value-of select="//TEI:facsimile//TEI:zone[@xml:id=$zoneID]/@ulx"/>
                        <xsl:text>,</xsl:text>
                        <xsl:value-of select="//TEI:facsimile//TEI:zone[@xml:id=$zoneID]/@uly"/>
                        <xsl:text>,</xsl:text>
                        <xsl:value-of select="//TEI:facsimile//TEI:zone[@xml:id=$zoneID]/@lrx"/>
                        <xsl:text>,</xsl:text>
                        <xsl:value-of select="//TEI:facsimile//TEI:zone[@xml:id=$zoneID]/@lry"/>
                        <xsl:text>,0.5)</xsl:text>
                    </xsl:attribute>

                    <!-- Attribut mit mouseout-Handler: Zeichenfläche wird gelöscht -->
                    <xsl:attribute name="onmouseout">
                        <xsl:text>erase()</xsl:text>
                    </xsl:attribute>
                    <xsl:apply-templates/>
                </span>
            </xsl:when>
            <xsl:otherwise>
                <xsl:apply-templates/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

</xsl:stylesheet>
